Class: Aws::BCMDashboards::Types::CostAndUsageQuery

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdashboards/types.rb

Overview

Defines the parameters for retrieving Amazon Web Services cost and usage data. Includes specifications for metrics, time periods, granularity, grouping dimensions, and filtering conditions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::Expression

The filter expression to be applied to the cost and usage data.

Returns:



77
78
79
80
81
82
83
84
85
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77

class CostAndUsageQuery < Struct.new(
  :metrics,
  :time_range,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#granularityString

The granularity of the retrieved data: ‘HOURLY`, `DAILY`, or `MONTHLY`.

Returns:

  • (String)


77
78
79
80
81
82
83
84
85
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77

class CostAndUsageQuery < Struct.new(
  :metrics,
  :time_range,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#group_byArray<Types::GroupDefinition>

Specifies how to group the retrieved data, such as by ‘SERVICE`, `ACCOUNT`, or `TAG`.

Returns:



77
78
79
80
81
82
83
84
85
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77

class CostAndUsageQuery < Struct.new(
  :metrics,
  :time_range,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<String>

The specific cost and usage metrics to retrieve.

<note markdown=“1”> Valid values for CostAndUsageQuery metrics are ‘AmortizedCost`, `BlendedCost`, `NetAmortizedCost`, `NetUnblendedCost`, `NormalizedUsageAmount`, `UnblendedCost`, and `UsageQuantity`.

</note>

Returns:

  • (Array<String>)


77
78
79
80
81
82
83
84
85
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77

class CostAndUsageQuery < Struct.new(
  :metrics,
  :time_range,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#time_rangeTypes::DateTimeRange

The time period for which to retrieve data. Can be specified as absolute dates or relative time periods.



77
78
79
80
81
82
83
84
85
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77

class CostAndUsageQuery < Struct.new(
  :metrics,
  :time_range,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end