Class: Aws::BCMDashboards::Types::CreateScheduledReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdashboards/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


177
178
179
180
181
182
183
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 177

class CreateScheduledReportRequest < Struct.new(
  :scheduled_report,
  :resource_tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_tagsArray<Types::ResourceTag>

The tags to apply to the scheduled report resource for organization and management.

Returns:



177
178
179
180
181
182
183
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 177

class CreateScheduledReportRequest < Struct.new(
  :scheduled_report,
  :resource_tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_reportTypes::ScheduledReportInput

The configuration for the scheduled report, including the dashboard to report on, the schedule, and the execution role that the service will use to generate the dashboard snapshot.



177
178
179
180
181
182
183
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 177

class CreateScheduledReportRequest < Struct.new(
  :scheduled_report,
  :resource_tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end