Class: Aws::BCMDashboards::Types::DimensionValues

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdashboards/types.rb

Overview

Specifies the values and match options for dimension-based filtering in cost and usage queries.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyString

The key of the dimension to filter on (for example, ‘SERVICE`, `USAGE_TYPE`, or `OPERATION`).

Returns:

  • (String)


346
347
348
349
350
351
352
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 346

class DimensionValues < Struct.new(
  :key,
  :values,
  :match_options)
  SENSITIVE = []
  include Aws::Structure
end

#match_optionsArray<String>

The match options for dimension values, such as ‘EQUALS`, `CONTAINS`, `STARTS_WITH`, or `ENDS_WITH`.

Returns:

  • (Array<String>)


346
347
348
349
350
351
352
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 346

class DimensionValues < Struct.new(
  :key,
  :values,
  :match_options)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<String>

The values to match for the specified dimension key.

Returns:

  • (Array<String>)


346
347
348
349
350
351
352
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 346

class DimensionValues < Struct.new(
  :key,
  :values,
  :match_options)
  SENSITIVE = []
  include Aws::Structure
end