Class: Aws::BCMDashboards::Types::ExecuteScheduledReportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::ExecuteScheduledReportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_triggered ⇒ Boolean
Indicates whether the execution was successfully triggered.
-
#health_status ⇒ Types::HealthStatus
The health status of the scheduled report after the execution request.
Instance Attribute Details
#execution_triggered ⇒ Boolean
Indicates whether the execution was successfully triggered.
424 425 426 427 428 429 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 424 class ExecuteScheduledReportResponse < Struct.new( :health_status, :execution_triggered) SENSITIVE = [] include Aws::Structure end |
#health_status ⇒ Types::HealthStatus
The health status of the scheduled report after the execution request.
424 425 426 427 428 429 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 424 class ExecuteScheduledReportResponse < Struct.new( :health_status, :execution_triggered) SENSITIVE = [] include Aws::Structure end |