Class: Aws::BCMDashboards::Types::HealthStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::HealthStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Contains the health status information for a scheduled report, including the status code and any reasons for an unhealthy state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_refreshed_at ⇒ Time
The timestamp when the health status was last refreshed.
-
#status_code ⇒ String
The health status code.
-
#status_reasons ⇒ Array<String>
The list of reasons for the current health status.
Instance Attribute Details
#last_refreshed_at ⇒ Time
The timestamp when the health status was last refreshed.
640 641 642 643 644 645 646 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 640 class HealthStatus < Struct.new( :status_code, :last_refreshed_at, :status_reasons) SENSITIVE = [] include Aws::Structure end |
#status_code ⇒ String
The health status code. ‘HEALTHY` indicates the scheduled report is configured properly and has all required permissions to execute. `UNHEALTHY` indicates the scheduled report is unable to deliver the notification to the default Amazon EventBridge EventBus in your account and your action is needed. The reason for the unhealthy state is captured in the health status reasons.
640 641 642 643 644 645 646 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 640 class HealthStatus < Struct.new( :status_code, :last_refreshed_at, :status_reasons) SENSITIVE = [] include Aws::Structure end |
#status_reasons ⇒ Array<String>
The list of reasons for the current health status. Only present when the status is ‘UNHEALTHY`.
640 641 642 643 644 645 646 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 640 class HealthStatus < Struct.new( :status_code, :last_refreshed_at, :status_reasons) SENSITIVE = [] include Aws::Structure end |