Class: Aws::BCMDashboards::Types::ReservationCoverageQuery
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::ReservationCoverageQuery
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Defines the parameters for querying Reserved Instance coverage data, including grouping options, metrics, and sorting preferences.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::Expression
Defines complex filtering conditions using logical operators (‘AND`, `OR`, `NOT`) and various filter types.
-
#granularity ⇒ String
The time granularity of the retrieved data: ‘HOURLY`, `DAILY`, or `MONTHLY`.
-
#group_by ⇒ Array<Types::GroupDefinition>
Specifies how to group the Reserved Instance coverage data, such as by service, Region, or instance type.
-
#metrics ⇒ Array<String>
The coverage metrics to include in the results.
-
#time_range ⇒ Types::DateTimeRange
Defines a time period with explicit start and end times for data queries.
Instance Attribute Details
#filter ⇒ Types::Expression
Defines complex filtering conditions using logical operators (‘AND`, `OR`, `NOT`) and various filter types.
849 850 851 852 853 854 855 856 857 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 849 class ReservationCoverageQuery < Struct.new( :time_range, :group_by, :granularity, :filter, :metrics) SENSITIVE = [] include Aws::Structure end |
#granularity ⇒ String
The time granularity of the retrieved data: ‘HOURLY`, `DAILY`, or `MONTHLY`.
849 850 851 852 853 854 855 856 857 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 849 class ReservationCoverageQuery < Struct.new( :time_range, :group_by, :granularity, :filter, :metrics) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ Array<Types::GroupDefinition>
Specifies how to group the Reserved Instance coverage data, such as by service, Region, or instance type.
849 850 851 852 853 854 855 856 857 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 849 class ReservationCoverageQuery < Struct.new( :time_range, :group_by, :granularity, :filter, :metrics) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<String>
The coverage metrics to include in the results.
<note markdown=“1”> Valid values for ReservationCoverageQuery metrics are ‘Hour`, `Unit`, and `Cost`.
</note>
849 850 851 852 853 854 855 856 857 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 849 class ReservationCoverageQuery < Struct.new( :time_range, :group_by, :granularity, :filter, :metrics) SENSITIVE = [] include Aws::Structure end |
#time_range ⇒ Types::DateTimeRange
Defines a time period with explicit start and end times for data queries.
849 850 851 852 853 854 855 856 857 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 849 class ReservationCoverageQuery < Struct.new( :time_range, :group_by, :granularity, :filter, :metrics) SENSITIVE = [] include Aws::Structure end |