Class: Aws::BCMDashboards::Types::SavingsPlansCoverageQuery

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdashboards/types.rb

Overview

Defines the parameters for querying Savings Plans coverage data, including metrics, grouping options, and time granularity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::Expression

Defines complex filtering conditions using logical operators (‘AND`, `OR`, `NOT`) and various filter types.

Returns:



961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961

class SavingsPlansCoverageQuery < Struct.new(
  :time_range,
  :metrics,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#granularityString

The time granularity of the retrieved data: ‘HOURLY`, `DAILY`, or `MONTHLY`.

Returns:

  • (String)


961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961

class SavingsPlansCoverageQuery < Struct.new(
  :time_range,
  :metrics,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#group_byArray<Types::GroupDefinition>

Specifies how to group the Savings Plans coverage data, such as by service or instance family.

Returns:



961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961

class SavingsPlansCoverageQuery < Struct.new(
  :time_range,
  :metrics,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<String>

The coverage metrics to include in the results.

<note markdown=“1”> Valid value for SavingsPlansCoverageQuery metrics is ‘SpendCoveredBySavingsPlans`.

</note>

Returns:

  • (Array<String>)


961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961

class SavingsPlansCoverageQuery < Struct.new(
  :time_range,
  :metrics,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#time_rangeTypes::DateTimeRange

Defines a time period with explicit start and end times for data queries.



961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961

class SavingsPlansCoverageQuery < Struct.new(
  :time_range,
  :metrics,
  :granularity,
  :group_by,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end