Class: Aws::BCMDashboards::Types::SavingsPlansUtilizationQuery

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdashboards/types.rb

Overview

Defines the parameters for querying Savings Plans utilization data, including time granularity and sorting preferences.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::Expression

Defines complex filtering conditions using logical operators (‘AND`, `OR`, `NOT`) and various filter types.

Returns:



991
992
993
994
995
996
997
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 991

class SavingsPlansUtilizationQuery < Struct.new(
  :time_range,
  :granularity,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#granularityString

The time granularity of the retrieved data: ‘HOURLY`, `DAILY`, or `MONTHLY`.

Returns:

  • (String)


991
992
993
994
995
996
997
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 991

class SavingsPlansUtilizationQuery < Struct.new(
  :time_range,
  :granularity,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#time_rangeTypes::DateTimeRange

Defines a time period with explicit start and end times for data queries.



991
992
993
994
995
996
997
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 991

class SavingsPlansUtilizationQuery < Struct.new(
  :time_range,
  :granularity,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end