Class: Aws::BCMDashboards::Types::ScheduleConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::ScheduleConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Defines the schedule for a scheduled report, including the cron expression, time zone, active period, and the schedule state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#schedule_expression ⇒ String
The schedule expression that specifies when to trigger the scheduled report run.
-
#schedule_expression_time_zone ⇒ String
The time zone for the schedule expression, for example, ‘UTC`.
-
#schedule_period ⇒ Types::SchedulePeriod
The time period during which the schedule is active.
-
#state ⇒ String
The state of the schedule.
Instance Attribute Details
#schedule_expression ⇒ String
The schedule expression that specifies when to trigger the scheduled report run. This value must be a cron expression consisting of six fields separated by white spaces: ‘cron(minutes hours day_of_month month day_of_week year)`.
1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1025 class ScheduleConfig < Struct.new( :schedule_expression, :schedule_expression_time_zone, :schedule_period, :state) SENSITIVE = [] include Aws::Structure end |
#schedule_expression_time_zone ⇒ String
The time zone for the schedule expression, for example, ‘UTC`.
1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1025 class ScheduleConfig < Struct.new( :schedule_expression, :schedule_expression_time_zone, :schedule_period, :state) SENSITIVE = [] include Aws::Structure end |
#schedule_period ⇒ Types::SchedulePeriod
The time period during which the schedule is active.
1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1025 class ScheduleConfig < Struct.new( :schedule_expression, :schedule_expression_time_zone, :schedule_period, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the schedule. ‘ENABLED` means the scheduled report runs according to its schedule expression. `DISABLED` means the scheduled report is paused and will not run until re-enabled.
1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1025 class ScheduleConfig < Struct.new( :schedule_expression, :schedule_expression_time_zone, :schedule_period, :state) SENSITIVE = [] include Aws::Structure end |