Class: Aws::BCMDashboards::Types::ScheduledReportInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdashboards/types.rb

Overview

Defines the configuration for creating a new scheduled report, including the dashboard, schedule, execution role, and optional widget settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard_arnString

The ARN of the dashboard to generate the scheduled report from.

Returns:

  • (String)


1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169

class ScheduledReportInput < Struct.new(
  :name,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :description,
  :widget_ids,
  :widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the scheduled report’s purpose or contents.

Returns:

  • (String)


1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169

class ScheduledReportInput < Struct.new(
  :name,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :description,
  :widget_ids,
  :widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the scheduled report.

Returns:

  • (String)


1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169

class ScheduledReportInput < Struct.new(
  :name,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :description,
  :widget_ids,
  :widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_configTypes::ScheduleConfig

The schedule configuration that defines when and how often the report is generated. If the schedule state is not specified, it defaults to ‘ENABLED`.



1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169

class ScheduledReportInput < Struct.new(
  :name,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :description,
  :widget_ids,
  :widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_report_execution_role_arnString

The ARN of the IAM role that the scheduled report uses to execute. Amazon Web Services Billing and Cost Management Dashboards will assume this IAM role while executing the scheduled report.

Returns:

  • (String)


1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169

class ScheduledReportInput < Struct.new(
  :name,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :description,
  :widget_ids,
  :widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#widget_date_range_overrideTypes::DateTimeRange

The date range override to apply to widgets in the scheduled report.



1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169

class ScheduledReportInput < Struct.new(
  :name,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :description,
  :widget_ids,
  :widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#widget_idsArray<String>

The list of widget identifiers to include in the scheduled report. If not specified, all widgets in the dashboard are included.

Returns:

  • (Array<String>)


1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169

class ScheduledReportInput < Struct.new(
  :name,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :description,
  :widget_ids,
  :widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end