Class: Aws::BCMDashboards::Types::ScheduledReportSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdashboards/types.rb

Overview

Contains summary information for a scheduled report.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the scheduled report.

Returns:

  • (String)


1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218

class ScheduledReportSummary < Struct.new(
  :arn,
  :name,
  :dashboard_arn,
  :schedule_expression,
  :state,
  :health_status,
  :schedule_expression_time_zone,
  :widget_ids)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_arnString

The ARN of the dashboard associated with the scheduled report.

Returns:

  • (String)


1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218

class ScheduledReportSummary < Struct.new(
  :arn,
  :name,
  :dashboard_arn,
  :schedule_expression,
  :state,
  :health_status,
  :schedule_expression_time_zone,
  :widget_ids)
  SENSITIVE = []
  include Aws::Structure
end

#health_statusTypes::HealthStatus

The health status of the scheduled report as of its last refresh time.

Returns:



1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218

class ScheduledReportSummary < Struct.new(
  :arn,
  :name,
  :dashboard_arn,
  :schedule_expression,
  :state,
  :health_status,
  :schedule_expression_time_zone,
  :widget_ids)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the scheduled report.

Returns:

  • (String)


1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218

class ScheduledReportSummary < Struct.new(
  :arn,
  :name,
  :dashboard_arn,
  :schedule_expression,
  :state,
  :health_status,
  :schedule_expression_time_zone,
  :widget_ids)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_expressionString

The schedule expression that defines when the report runs.

Returns:

  • (String)


1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218

class ScheduledReportSummary < Struct.new(
  :arn,
  :name,
  :dashboard_arn,
  :schedule_expression,
  :state,
  :health_status,
  :schedule_expression_time_zone,
  :widget_ids)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_expression_time_zoneString

The time zone for the schedule expression, for example, ‘UTC`.

Returns:

  • (String)


1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218

class ScheduledReportSummary < Struct.new(
  :arn,
  :name,
  :dashboard_arn,
  :schedule_expression,
  :state,
  :health_status,
  :schedule_expression_time_zone,
  :widget_ids)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the schedule: ‘ENABLED` or `DISABLED`.

Returns:

  • (String)


1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218

class ScheduledReportSummary < Struct.new(
  :arn,
  :name,
  :dashboard_arn,
  :schedule_expression,
  :state,
  :health_status,
  :schedule_expression_time_zone,
  :widget_ids)
  SENSITIVE = []
  include Aws::Structure
end

#widget_idsArray<String>

The list of widget identifiers included in the scheduled report.

Returns:

  • (Array<String>)


1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218

class ScheduledReportSummary < Struct.new(
  :arn,
  :name,
  :dashboard_arn,
  :schedule_expression,
  :state,
  :health_status,
  :schedule_expression_time_zone,
  :widget_ids)
  SENSITIVE = []
  include Aws::Structure
end