Class: Aws::BCMDashboards::Types::UpdateScheduledReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdashboards/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the scheduled report to update.

Returns:

  • (String)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#clear_widget_date_range_overrideBoolean

Set to true to clear existing widgetDateRangeOverride.

Returns:

  • (Boolean)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#clear_widget_idsBoolean

Set to true to clear existing widgetIds.

Returns:

  • (Boolean)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_arnString

The ARN of the dashboard to associate with the scheduled report.

Returns:

  • (String)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The new description for the scheduled report.

Returns:

  • (String)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The new name for the scheduled report.

Returns:

  • (String)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_configTypes::ScheduleConfig

The updated schedule configuration for the report.



1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_report_execution_role_arnString

The ARN of the IAM role that the scheduled report uses to execute. Amazon Web Services Billing and Cost Management Dashboards will assume this IAM role while executing the scheduled report.

Returns:

  • (String)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#widget_date_range_overrideTypes::DateTimeRange

The date range override to apply to widgets in the scheduled report.



1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end

#widget_idsArray<String>

The list of widget identifiers to include in the scheduled report. If not specified, all widgets in the dashboard are included.

Returns:

  • (Array<String>)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421

class UpdateScheduledReportRequest < Struct.new(
  :arn,
  :name,
  :description,
  :dashboard_arn,
  :scheduled_report_execution_role_arn,
  :schedule_config,
  :widget_ids,
  :widget_date_range_override,
  :clear_widget_ids,
  :clear_widget_date_range_override)
  SENSITIVE = []
  include Aws::Structure
end