Class: Aws::BCMDashboards::Types::CostAndUsageQuery
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::CostAndUsageQuery
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Defines the parameters for retrieving Amazon Web Services cost and usage data. Includes specifications for metrics, time periods, granularity, grouping dimensions, and filtering conditions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::Expression
The filter expression to be applied to the cost and usage data.
-
#granularity ⇒ String
The granularity of the retrieved data: ‘HOURLY`, `DAILY`, or `MONTHLY`.
-
#group_by ⇒ Array<Types::GroupDefinition>
Specifies how to group the retrieved data, such as by ‘SERVICE`, `ACCOUNT`, or `TAG`.
-
#metrics ⇒ Array<String>
The specific cost and usage metrics to retrieve.
-
#time_range ⇒ Types::DateTimeRange
The time period for which to retrieve data.
Instance Attribute Details
#filter ⇒ Types::Expression
The filter expression to be applied to the cost and usage data.
77 78 79 80 81 82 83 84 85 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77 class CostAndUsageQuery < Struct.new( :metrics, :time_range, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |
#granularity ⇒ String
The granularity of the retrieved data: ‘HOURLY`, `DAILY`, or `MONTHLY`.
77 78 79 80 81 82 83 84 85 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77 class CostAndUsageQuery < Struct.new( :metrics, :time_range, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ Array<Types::GroupDefinition>
Specifies how to group the retrieved data, such as by ‘SERVICE`, `ACCOUNT`, or `TAG`.
77 78 79 80 81 82 83 84 85 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77 class CostAndUsageQuery < Struct.new( :metrics, :time_range, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<String>
The specific cost and usage metrics to retrieve.
<note markdown=“1”> Valid values for CostAndUsageQuery metrics are ‘AmortizedCost`, `BlendedCost`, `NetAmortizedCost`, `NetUnblendedCost`, `NormalizedUsageAmount`, `UnblendedCost`, and `UsageQuantity`.
</note>
77 78 79 80 81 82 83 84 85 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77 class CostAndUsageQuery < Struct.new( :metrics, :time_range, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |
#time_range ⇒ Types::DateTimeRange
The time period for which to retrieve data. Can be specified as absolute dates or relative time periods.
77 78 79 80 81 82 83 84 85 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 77 class CostAndUsageQuery < Struct.new( :metrics, :time_range, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |