Class: Aws::BCMDashboards::Types::CreateScheduledReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::CreateScheduledReportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#resource_tags ⇒ Array<Types::ResourceTag>
The tags to apply to the scheduled report resource for organization and management.
-
#scheduled_report ⇒ Types::ScheduledReportInput
The configuration for the scheduled report, including the dashboard to report on, the schedule, and the execution role that the service will use to generate the dashboard snapshot.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
177 178 179 180 181 182 183 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 177 class CreateScheduledReportRequest < Struct.new( :scheduled_report, :resource_tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_tags ⇒ Array<Types::ResourceTag>
The tags to apply to the scheduled report resource for organization and management.
177 178 179 180 181 182 183 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 177 class CreateScheduledReportRequest < Struct.new( :scheduled_report, :resource_tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#scheduled_report ⇒ Types::ScheduledReportInput
The configuration for the scheduled report, including the dashboard to report on, the schedule, and the execution role that the service will use to generate the dashboard snapshot.
177 178 179 180 181 182 183 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 177 class CreateScheduledReportRequest < Struct.new( :scheduled_report, :resource_tags, :client_token) SENSITIVE = [] include Aws::Structure end |