Class: Aws::BCMDashboards::Types::ExecuteScheduledReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::ExecuteScheduledReportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the scheduled report to execute.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
When set to ‘true`, validates the scheduled report configuration without triggering an actual execution.
Instance Attribute Details
#arn ⇒ String
The ARN of the scheduled report to execute.
405 406 407 408 409 410 411 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 405 class ExecuteScheduledReportRequest < Struct.new( :arn, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
405 406 407 408 409 410 411 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 405 class ExecuteScheduledReportRequest < Struct.new( :arn, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
When set to ‘true`, validates the scheduled report configuration without triggering an actual execution.
405 406 407 408 409 410 411 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 405 class ExecuteScheduledReportRequest < Struct.new( :arn, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |