Class: Aws::BCMDashboards::Types::SavingsPlansCoverageQuery
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::SavingsPlansCoverageQuery
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Defines the parameters for querying Savings Plans coverage data, including metrics, grouping options, and time granularity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::Expression
Defines complex filtering conditions using logical operators (‘AND`, `OR`, `NOT`) and various filter types.
-
#granularity ⇒ String
The time granularity of the retrieved data: ‘HOURLY`, `DAILY`, or `MONTHLY`.
-
#group_by ⇒ Array<Types::GroupDefinition>
Specifies how to group the Savings Plans coverage data, such as by service or instance family.
-
#metrics ⇒ Array<String>
The coverage metrics to include in the results.
-
#time_range ⇒ Types::DateTimeRange
Defines a time period with explicit start and end times for data queries.
Instance Attribute Details
#filter ⇒ Types::Expression
Defines complex filtering conditions using logical operators (‘AND`, `OR`, `NOT`) and various filter types.
961 962 963 964 965 966 967 968 969 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961 class SavingsPlansCoverageQuery < Struct.new( :time_range, :metrics, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |
#granularity ⇒ String
The time granularity of the retrieved data: ‘HOURLY`, `DAILY`, or `MONTHLY`.
961 962 963 964 965 966 967 968 969 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961 class SavingsPlansCoverageQuery < Struct.new( :time_range, :metrics, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ Array<Types::GroupDefinition>
Specifies how to group the Savings Plans coverage data, such as by service or instance family.
961 962 963 964 965 966 967 968 969 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961 class SavingsPlansCoverageQuery < Struct.new( :time_range, :metrics, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<String>
The coverage metrics to include in the results.
<note markdown=“1”> Valid value for SavingsPlansCoverageQuery metrics is ‘SpendCoveredBySavingsPlans`.
</note>
961 962 963 964 965 966 967 968 969 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961 class SavingsPlansCoverageQuery < Struct.new( :time_range, :metrics, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |
#time_range ⇒ Types::DateTimeRange
Defines a time period with explicit start and end times for data queries.
961 962 963 964 965 966 967 968 969 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 961 class SavingsPlansCoverageQuery < Struct.new( :time_range, :metrics, :granularity, :group_by, :filter) SENSITIVE = [] include Aws::Structure end |