Class: Aws::BCMDashboards::Types::ScheduledReport
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::ScheduledReport
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Contains the full configuration and metadata of a scheduled report.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the scheduled report.
-
#created_at ⇒ Time
The timestamp when the scheduled report was created.
-
#dashboard_arn ⇒ String
The ARN of the dashboard associated with the scheduled report.
-
#description ⇒ String
A description of the scheduled report’s purpose or contents.
-
#health_status ⇒ Types::HealthStatus
The health status of the scheduled report at last refresh time.
-
#last_execution_at ⇒ Time
The timestamp of the most recent execution of the scheduled report.
-
#name ⇒ String
The name of the scheduled report.
-
#schedule_config ⇒ Types::ScheduleConfig
The schedule configuration that defines when and how often the report is generated.
-
#scheduled_report_execution_role_arn ⇒ String
The ARN of the IAM role that the scheduled report uses to execute.
-
#updated_at ⇒ Time
The timestamp when the scheduled report was last modified.
-
#widget_date_range_override ⇒ Types::DateTimeRange
The date range override applied to widgets in the scheduled report.
-
#widget_ids ⇒ Array<String>
The list of widget identifiers included in the scheduled report.
Instance Attribute Details
#arn ⇒ String
The ARN of the scheduled report.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the scheduled report was created.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#dashboard_arn ⇒ String
The ARN of the dashboard associated with the scheduled report.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the scheduled report’s purpose or contents.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#health_status ⇒ Types::HealthStatus
The health status of the scheduled report at last refresh time.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#last_execution_at ⇒ Time
The timestamp of the most recent execution of the scheduled report.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the scheduled report.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#schedule_config ⇒ Types::ScheduleConfig
The schedule configuration that defines when and how often the report is generated.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#scheduled_report_execution_role_arn ⇒ String
The ARN of the IAM role that the scheduled report uses to execute. Amazon Web Services Billing and Cost Management Dashboards will assume this IAM role while executing the scheduled report.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the scheduled report was last modified.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#widget_date_range_override ⇒ Types::DateTimeRange
The date range override applied to widgets in the scheduled report.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |
#widget_ids ⇒ Array<String>
The list of widget identifiers included in the scheduled report.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1113 class ScheduledReport < Struct.new( :arn, :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override, :created_at, :updated_at, :last_execution_at, :health_status) SENSITIVE = [] include Aws::Structure end |