Class: Aws::BCMDashboards::Types::ScheduledReportInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::ScheduledReportInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Defines the configuration for creating a new scheduled report, including the dashboard, schedule, execution role, and optional widget settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dashboard_arn ⇒ String
The ARN of the dashboard to generate the scheduled report from.
-
#description ⇒ String
A description of the scheduled report’s purpose or contents.
-
#name ⇒ String
The name of the scheduled report.
-
#schedule_config ⇒ Types::ScheduleConfig
The schedule configuration that defines when and how often the report is generated.
-
#scheduled_report_execution_role_arn ⇒ String
The ARN of the IAM role that the scheduled report uses to execute.
-
#widget_date_range_override ⇒ Types::DateTimeRange
The date range override to apply to widgets in the scheduled report.
-
#widget_ids ⇒ Array<String>
The list of widget identifiers to include in the scheduled report.
Instance Attribute Details
#dashboard_arn ⇒ String
The ARN of the dashboard to generate the scheduled report from.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169 class ScheduledReportInput < Struct.new( :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the scheduled report’s purpose or contents.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169 class ScheduledReportInput < Struct.new( :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the scheduled report.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169 class ScheduledReportInput < Struct.new( :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#schedule_config ⇒ Types::ScheduleConfig
The schedule configuration that defines when and how often the report is generated. If the schedule state is not specified, it defaults to ‘ENABLED`.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169 class ScheduledReportInput < Struct.new( :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#scheduled_report_execution_role_arn ⇒ String
The ARN of the IAM role that the scheduled report uses to execute. Amazon Web Services Billing and Cost Management Dashboards will assume this IAM role while executing the scheduled report.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169 class ScheduledReportInput < Struct.new( :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#widget_date_range_override ⇒ Types::DateTimeRange
The date range override to apply to widgets in the scheduled report.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169 class ScheduledReportInput < Struct.new( :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#widget_ids ⇒ Array<String>
The list of widget identifiers to include in the scheduled report. If not specified, all widgets in the dashboard are included.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1169 class ScheduledReportInput < Struct.new( :name, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :description, :widget_ids, :widget_date_range_override) SENSITIVE = [] include Aws::Structure end |