Class: Aws::BCMDashboards::Types::ScheduledReportSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::ScheduledReportSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Contains summary information for a scheduled report.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the scheduled report.
-
#dashboard_arn ⇒ String
The ARN of the dashboard associated with the scheduled report.
-
#health_status ⇒ Types::HealthStatus
The health status of the scheduled report as of its last refresh time.
-
#name ⇒ String
The name of the scheduled report.
-
#schedule_expression ⇒ String
The schedule expression that defines when the report runs.
-
#schedule_expression_time_zone ⇒ String
The time zone for the schedule expression, for example, ‘UTC`.
-
#state ⇒ String
The state of the schedule: ‘ENABLED` or `DISABLED`.
-
#widget_ids ⇒ Array<String>
The list of widget identifiers included in the scheduled report.
Instance Attribute Details
#arn ⇒ String
The ARN of the scheduled report.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218 class ScheduledReportSummary < Struct.new( :arn, :name, :dashboard_arn, :schedule_expression, :state, :health_status, :schedule_expression_time_zone, :widget_ids) SENSITIVE = [] include Aws::Structure end |
#dashboard_arn ⇒ String
The ARN of the dashboard associated with the scheduled report.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218 class ScheduledReportSummary < Struct.new( :arn, :name, :dashboard_arn, :schedule_expression, :state, :health_status, :schedule_expression_time_zone, :widget_ids) SENSITIVE = [] include Aws::Structure end |
#health_status ⇒ Types::HealthStatus
The health status of the scheduled report as of its last refresh time.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218 class ScheduledReportSummary < Struct.new( :arn, :name, :dashboard_arn, :schedule_expression, :state, :health_status, :schedule_expression_time_zone, :widget_ids) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the scheduled report.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218 class ScheduledReportSummary < Struct.new( :arn, :name, :dashboard_arn, :schedule_expression, :state, :health_status, :schedule_expression_time_zone, :widget_ids) SENSITIVE = [] include Aws::Structure end |
#schedule_expression ⇒ String
The schedule expression that defines when the report runs.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218 class ScheduledReportSummary < Struct.new( :arn, :name, :dashboard_arn, :schedule_expression, :state, :health_status, :schedule_expression_time_zone, :widget_ids) SENSITIVE = [] include Aws::Structure end |
#schedule_expression_time_zone ⇒ String
The time zone for the schedule expression, for example, ‘UTC`.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218 class ScheduledReportSummary < Struct.new( :arn, :name, :dashboard_arn, :schedule_expression, :state, :health_status, :schedule_expression_time_zone, :widget_ids) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the schedule: ‘ENABLED` or `DISABLED`.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218 class ScheduledReportSummary < Struct.new( :arn, :name, :dashboard_arn, :schedule_expression, :state, :health_status, :schedule_expression_time_zone, :widget_ids) SENSITIVE = [] include Aws::Structure end |
#widget_ids ⇒ Array<String>
The list of widget identifiers included in the scheduled report.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1218 class ScheduledReportSummary < Struct.new( :arn, :name, :dashboard_arn, :schedule_expression, :state, :health_status, :schedule_expression_time_zone, :widget_ids) SENSITIVE = [] include Aws::Structure end |