Class: Aws::BCMDashboards::Types::UpdateScheduledReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDashboards::Types::UpdateScheduledReportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdashboards/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the scheduled report to update.
-
#clear_widget_date_range_override ⇒ Boolean
Set to true to clear existing widgetDateRangeOverride.
-
#clear_widget_ids ⇒ Boolean
Set to true to clear existing widgetIds.
-
#dashboard_arn ⇒ String
The ARN of the dashboard to associate with the scheduled report.
-
#description ⇒ String
The new description for the scheduled report.
-
#name ⇒ String
The new name for the scheduled report.
-
#schedule_config ⇒ Types::ScheduleConfig
The updated schedule configuration for the report.
-
#scheduled_report_execution_role_arn ⇒ String
The ARN of the IAM role that the scheduled report uses to execute.
-
#widget_date_range_override ⇒ Types::DateTimeRange
The date range override to apply to widgets in the scheduled report.
-
#widget_ids ⇒ Array<String>
The list of widget identifiers to include in the scheduled report.
Instance Attribute Details
#arn ⇒ String
The ARN of the scheduled report to update.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#clear_widget_date_range_override ⇒ Boolean
Set to true to clear existing widgetDateRangeOverride.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#clear_widget_ids ⇒ Boolean
Set to true to clear existing widgetIds.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#dashboard_arn ⇒ String
The ARN of the dashboard to associate with the scheduled report.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The new description for the scheduled report.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The new name for the scheduled report.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#schedule_config ⇒ Types::ScheduleConfig
The updated schedule configuration for the report.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#scheduled_report_execution_role_arn ⇒ String
The ARN of the IAM role that the scheduled report uses to execute. Amazon Web Services Billing and Cost Management Dashboards will assume this IAM role while executing the scheduled report.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#widget_date_range_override ⇒ Types::DateTimeRange
The date range override to apply to widgets in the scheduled report.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |
#widget_ids ⇒ Array<String>
The list of widget identifiers to include in the scheduled report. If not specified, all widgets in the dashboard are included.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-bcmdashboards/types.rb', line 1421 class UpdateScheduledReportRequest < Struct.new( :arn, :name, :description, :dashboard_arn, :scheduled_report_execution_role_arn, :schedule_config, :widget_ids, :widget_date_range_override, :clear_widget_ids, :clear_widget_date_range_override) SENSITIVE = [] include Aws::Structure end |